# Unknown SearchSource

## search

### DB Search

**load**

- Typical Excel column names include: ...

Download search results and store in `data/search/` directory. API-access not available (per definition).

## Links
